import { Link } from "wouter";
import { ArrowRight, ArrowDown } from "lucide-react";
import cedricPhoto from "@assets/cedric-photo.png";
import cedricPhotoWebP from "@assets/cedric-photo.webp";

interface HeroSectionProps {
  content: {
    title: string;
    subtitle: string;
    description1: string;
    description2: string;
    cta1: string;
    cta2: string;
  };
  language: string;
}

export default function HeroSection({ content, language }: HeroSectionProps) {
  return (
    <section className="relative min-h-[80vh] flex items-center bg-background overflow-hidden pt-20 sm:pt-24 lg:pt-0">
      {/* Gradient Background */}
      <div className="absolute inset-0 bg-gradient-to-br from-gray-50/80 via-white to-gray-50/40"></div>
      
      {/* Content Container */}
      <div className="relative z-10 w-full max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8 lg:py-12">
        <div className="grid lg:grid-cols-2 gap-8 lg:gap-12 xl:gap-16 items-center">
          
          {/* Left Content */}
          <div className="space-y-4 sm:space-y-6 text-left">
            <h1 className="text-xl sm:text-2xl md:text-3xl lg:text-4xl xl:text-5xl font-extralight leading-[1.1] sm:leading-[1.05] tracking-tight text-foreground reveal-sequence-1">
              {content.title}
            </h1>
            
            <p className="text-base sm:text-lg md:text-xl text-accent font-light reveal-sequence-1">
              {content.subtitle}
            </p>
            
            <div className="space-y-3 sm:space-y-4 mb-6 sm:mb-8">
              <p className="text-sm sm:text-base md:text-lg font-light text-neutral-gray leading-[1.4] reveal-sequence-2">
                {content.description1}
              </p>
              
              <p className="text-sm sm:text-base font-light text-neutral-gray/80 reveal-sequence-2">
                {content.description2}
              </p>
            </div>
            
            {/* Clean Premium CTAs - Primary/Secondary Hierarchy */}
            <div className="reveal-sequence-3">
              <div className="flex flex-col sm:flex-row gap-3 sm:gap-4">
                <Link 
                  href={`/${language}/contact`} 
                  className="inline-flex items-center justify-center px-6 sm:px-8 py-4 sm:py-4 bg-accent text-white rounded-2xl hover:bg-accent/90 transition-all duration-300 font-semibold shadow-lg hover:shadow-xl transform hover:-translate-y-1 group text-base sm:text-lg min-h-[48px] touch-manipulation"
                >
                  {content.cta1}
                  <ArrowRight className="w-4 sm:w-5 h-4 sm:h-5 ml-2 group-hover:translate-x-1 transition-transform" />
                </Link>
                
                <a 
                  href="#story" 
                  className="inline-flex items-center justify-center px-5 sm:px-6 py-3 bg-white/60 border border-gray-200/60 rounded-2xl hover:bg-white/80 hover:border-accent/30 transition-all duration-300 font-medium shadow-sm hover:shadow-md group backdrop-blur-sm text-neutral-gray hover:text-foreground text-sm sm:text-base"
                  onClick={(e) => {
                    e.preventDefault();
                    const targetElement = document.getElementById('story');
                    if (targetElement) {
                      targetElement.scrollIntoView({ 
                        behavior: 'smooth',
                        block: 'start'
                      });
                    }
                  }}
                >
                  {content.cta2}
                  <ArrowDown className="w-4 h-4 ml-2 group-hover:translate-y-1 transition-transform" />
                </a>
              </div>
            </div>
          </div>
          
          {/* Right Image */}
          <div className="relative mt-8 lg:mt-0 flex items-center justify-center reveal-sequence-4">
            <div className="relative w-full max-w-lg mx-auto">
              <div className="relative overflow-hidden rounded-3xl shadow-2xl group">
                <picture>
                  <source srcSet={cedricPhotoWebP} type="image/webp" />
                  <img 
                    src={cedricPhoto} 
                    alt="Cedric de Vlieger - Leadership expert with Special Units background"
                    className="w-full h-auto object-cover transition-all duration-500 group-hover:scale-105"
                    loading="eager"
                    {...({ fetchpriority: 'high' } as any)}
                    decoding="async"
                    style={{ aspectRatio: '4/5' }}
                  />
                </picture>
                
                {/* Subtle caption frame - positioned over the image */}
                <div className="absolute bottom-4 left-4 right-4 bg-white/95 backdrop-blur-sm border border-gray-100/60 rounded-2xl px-4 py-3 shadow-lg">
                  <p className="text-sm font-medium text-foreground">Cedric 'Fly' De Vlieger</p>
                  <p className="text-xs text-neutral-gray flex items-center">
                    Forged in special units 
                    <span className="mx-2 text-accent">→</span>
                    focused on leadership and team performance
                  </p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}